--[[
    Botman - A collection of scripts for managing 7 Days to Die servers
    Copyright (C) 2020  Matthew Dwyer
	           This copyright applies to the Lua source code in this Mudlet profile.
    Email     smegzor@gmail.com
    URL       https://botman.nz
    Source    https://bitbucket.org/mhdwyer/botman
--]]

local counter, status, debug, n, help

debug = false -- should be false unless testing

function gmsg_mail()
	local playerName, isArchived

	if botman.debugAll then
		debug = true -- this should be true
	end

	calledFunction = "gmsg_mail"

	if (debug) then dbug("debug mail line " .. debugger.getinfo(1).currentline) end

	-- ###################  do not run remote commands beyond this point unless displaying command help ################
	if chatvars.playerid == 0 and not (chatvars.showHelp or botman.registerHelp) then
		botman.faultyChat = false
		return false
	end
	-- ###################  do not run remote commands beyond this point unless displaying command help ################

	if (chatvars.words[1] == "pm" and chatvars.words[2] ~= nil) then
		if string.find(chatvars.words[2], "admin") then
			msg = string.sub(chatvars.commandOld, string.find(chatvars.commandOld, chatvars.wordsOld[2]) + string.len(chatvars.wordsOld[2]), string.len(chatvars.commandOld))
			msg = "PM from " .. chatvars.playername .. ", " .. msg
			alertAdmins(msg, "chat")

			if chatvars.accessLevel > 2 then
				message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Dankeschön. Ein Admin kann auf deine private Nachricht antworten.[-]")
			end

			botman.faultyChat = false
			return true
		end

		if string.find(chatvars.words[2], "tag") then
			msg = string.sub(chatvars.commandOld, string.find(chatvars.commandOld, chatvars.wordsOld[3]) + string.len(chatvars.wordsOld[3]), string.len(chatvars.commandOld))
			msg = "PM from " .. chatvars.playername .. ", " .. msg

			for k,v in pairs(igplayers) do
				if string.find(v.name, chatvars.wordsOld[3]) then
					message("pm " .. k .. " [" .. server.chatColour .. "]" .. msg .. "[-]")
				end
			end

			message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Nachricht an alle Spieler gesendet " .. chatvars.wordsOld[3] .. " Spieler, welche sich gerade im Spiel befinden.[-]")

			botman.faultyChat = false
			return true
		end

		msg = string.sub(chatvars.commandOld, 4, string.len(chatvars.commandOld))

		irc_chat(server.ircMain, server.gameDate .. " " .. chatvars.playername .. " said " .. msg)
		message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Deine versteckte Nachricht wurde an IRC gesendet.[-]")

		botman.faultyChat = false
		return true
	end


	-- ####################################################################################
	-- don't proceed if there is no leading slash or pm
	if (string.sub(chatvars.command, 1, 1) ~= server.commandPrefix and server.commandPrefix ~= "") and not (string.find(chatvars.oldLine, " command 'pm") or string.find(chatvars.oldLine, " command '@")) then
		botman.faultyChat = false
		return false
	end
	-- ####################################################################################

	if (debug) then dbug("debug mail line " .. debugger.getinfo(1).currentline) end

	if (chatvars.words[1] == "read" and chatvars.words[2] == "mail") then
		counter = 1

		if chatvars.number ~= nil then
			cursor,errorString = connSQL:execute("SELECT * FROM mail WHERE recipient = '" .. chatvars.playerid .. "'")
		else
			cursor,errorString = connSQL:execute("SELECT * FROM mail WHERE recipient = '" .. chatvars.playerid .. "' AND status = 0")
		end

		row = cursor:fetch({}, "a")
		while row do
			if chatvars.number ~= nil then
				if tonumber(chatvars.number) == counter then
					connSQL:execute("UPDATE mail SET status = 1 WHERE id = " .. row.id)
					message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Nachricht #" .. counter .. "[-]")
					message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]" .. row.message .. "[-]")
				end
			else
				connSQL:execute("UPDATE mail SET status = 1 WHERE id = " .. row.id)
				message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]" .. row.message .. "[-]")
			end

			counter = counter + 1
			row = cursor:fetch(row, "a")
		end

		botman.faultyChat = false
		return true
	end

	if (debug) then dbug("debug mail line " .. debugger.getinfo(1).currentline) end

	if (chatvars.words[1] == "list" and chatvars.words[2] == "mail") then
		counter = 1

		cursor,errorString = connSQL:execute("SELECT * FROM mail WHERE recipient = '" .. chatvars.playerid .. "'")
		row = cursor:fetch({}, "a")
		while row do
			if row.status == "0" then status = " [NEW]" end
			if row.status == "1" then status = " [SEEN]" end
			if row.status == "2" then status = " [SAVED]" end

			if tonumber(row.sender) == 0 then
				message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "](" .. counter .. ")  Nachricht vom Server" .. status .. " " .. string.sub(row.message, 1, 100) .. "..[-]")
			else
				message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "](" .. counter .. ")  Nachricht von " .. players[row.sender].name .. status .. " " .. string.sub(row.message, 1, 100) .. "..[-]")
			end

			counter = counter + 1
			row = cursor:fetch(row, "a")
		end

		botman.faultyChat = false
		return true
	end

	if (debug) then dbug("debug mail line " .. debugger.getinfo(1).currentline) end

	if (chatvars.words[1] == "save" and chatvars.words[2] == "mail" and chatvars.number ~= nil) then
		counter = 1

		cursor,errorString = connSQL:execute("SELECT * FROM mail WHERE recipient = '" .. chatvars.playerid .. "'")
		row = cursor:fetch({}, "a")
		while row do
			if tonumber(chatvars.number) == counter then
				connSQL:execute("UPDATE mail SET status = 2 WHERE id = " .. row.id)
				message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Nachricht (" .. counter .. ") gespeichert.[-]")

				botman.faultyChat = false
				return true
			end
		end

		botman.faultyChat = false
		return true
	end

	if (debug) then dbug("debug mail line " .. debugger.getinfo(1).currentline) end

	if (chatvars.words[1] == "delete" and chatvars.words[2] == "mail" and chatvars.number ~= nil) then
		counter = 1

		cursor,errorString = connSQL:execute("SELECT * FROM mail WHERE recipient = '" .. chatvars.playerid .. "'")
		row = cursor:fetch({}, "a")
		while row do
			if tonumber(chatvars.number) == counter then
				connSQL:execute("DELETE FROM mail WHERE id = " .. row.id)
				message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Nachricht (" .. counter .. ") gelöscht.[-]")

				botman.faultyChat = false
				return true
			end

			counter = counter + 1
			row = cursor:fetch(row, "a")
		end

		botman.faultyChat = false
		return true
	end

	if debug then dbug("debug mail end of remote commands") end

	-- ####################################################################################
	-- don't proceed if commands not hidden
	if not server.hideCommands then
		botman.faultyChat = false
		return false
	end
	-- ####################################################################################

	if (debug) then dbug("debug mail line " .. debugger.getinfo(1).currentline) end

	if (string.find(chatvars.words[1], "@", nil, true) and chatvars.words[2] ~= nil) then
		pname = string.sub(chatvars.words[1], string.find(chatvars.words[1], "@", nil, true) + 1, string.len(chatvars.words[1]))
		pname = string.trim(pname)

		id = LookupPlayer(pname)

		if id == 0 then
			id = LookupArchivedPlayer(pname)

			if not (id == 0) then
				playerName = playersArchived[id].name
				isArchived = true
			end
		end

		n = string.len(chatvars.wordsOld[1]) + 1
		msg = string.sub(chatvars.oldLine, string.find(chatvars.oldLine, chatvars.wordsOld[1], nil, true) + n), string.len(chatvars.oldLine)
		msg = stripQuotes(msg)

if debug then dbug("debug mail msg" .. msg) end

		if string.lower(pname) == "admin" or  string.lower(pname) == "admins" then
			for k,v in pairs(players) do
				if isAdmin(k) then
					if igplayers[k] then
						message("pm " .. v.userID .. " [" .. server.chatColour .. "]Nachricht von " .. players[chatvars.playerid].name .. ": " .. msg .. "[-]")
					else
						connSQL:execute("INSERT INTO mail (sender, recipient, message) VALUES ('" .. chatvars.playerid .. "','" .. k .. "', '" .. connMEM:escape(msg) .. "')")
					end
				end
			end

			message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Dankeschön. Ein Admin wird deine Nachricht bald erhalten.[-]")

			botman.faultyChat = false
			return true
		end

		if id ~= 0 then
			if isFriend(id, chatvars.playerid) or chatvars.accessLevel < 3 then
				if igplayers[id] then
					message("pm " .. igplayers[id].userID .. " [" .. server.chatColour .. "]Nachricht von " .. players[chatvars.playerid].name .. ": " .. msg .. "[-]")
					message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]" .. players[id].name .. " hat deine Nachricht erhalten.[-]")
				else
					if not isArchived then
						connSQL:execute("INSERT INTO mail (sender, recipient, message) VALUES ('" .. chatvars.playerid .. "','" .. id .. "', '" .. connMEM:escape(msg) .. "')")
						message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]" .. players[id].name .. " wird deine Nachricht erhalten, wenn er/sie zurückkommt.[-]")
					else
						connSQL:execute("INSERT INTO mail (sender, recipient, message) VALUES ('" .. chatvars.playerid .. "','" .. id .. "', '" .. connMEM:escape(msg) .. "')")
						message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]" .. playerName .. " wird deine Nachricht erhalten, wenn er/sie zurückkommt.[-]")
					end
				end
			else
				message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]" .. players[id].name .. " hat sich von nicht mit dir befreundet, deshalb bist du nicht befugt private Nachrichten zu senden.[-]")
			end
		else
			message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Ich kenne keinen Spieler mit dem Namen " .. pname .. "[-]")
		end

		botman.faultyChat = false
		return true
	end

if debug then dbug("debug mail end") end

end
