--[[
    Botman - A collection of scripts for managing 7 Days to Die servers
    Copyright (C) 2022  Matthew Dwyer
	           This copyright applies to the Lua source code in this Mudlet profile.
    Email     smegzor@gmail.com
    URL       https://botman.nz
    Source    https://bitbucket.org/mhdwyer/botman
--]]

function gmsg_unslashed()
	local debug, r, l
	local shortHelp = false
	local skipHelp = false

	debug = false -- should be false unless testing

	calledFunction = "gmsg_unslashed"

	if botman.debugAll then
		debug = true -- this should be true
	end

	if chatvars.showHelp then
		if chatvars.words[3] then
			if not string.find(chatvars.words[3], "unslashed") then
				skipHelp = true
			end
		end

		if chatvars.words[1] == "help" then
			skipHelp = false
		end

		if chatvars.words[1] == "list" then
			shortHelp = true
		end
	end

	if chatvars.showHelp and not skipHelp and chatvars.words[1] ~= "help" then
		irc_chat(chatvars.ircAlias, ".")
		irc_chat(chatvars.ircAlias, "Unslashed Commands:")
		irc_chat(chatvars.ircAlias, "===================")
		irc_chat(chatvars.ircAlias, ".")
		irc_chat(chatvars.ircAlias, "Unslashed commands are simply words in normal chat that trigger a response from the bot.")
		irc_chat(chatvars.ircAlias, ".")
		irc_chat(chatvars.ircAlias, "Your bot will react to any player using the words hack, cheat, grief or flying.  That triggers a special scan for hackers.")
		irc_chat(chatvars.ircAlias, "Any players with a non-zero hacker score found near the player will be immediately exiled.  If you don't have the exile location set up, nothing will happen.")
		irc_chat(chatvars.ircAlias, ".")
		irc_chat(chatvars.ircAlias, "When feral.  Like " .. server.commandPrefix .. "day7, the bot will report how many days remain until a horde night.")
		irc_chat(chatvars.ircAlias, "When reboot.  The bot will report how long until the next reboot.")
		irc_chat(chatvars.ircAlias, ".")
	end

	if chatvars.showHelpSections then
		irc_chat(chatvars.ircAlias, "unslashed")
	end

	if chatvars.showHelp and not skipHelp then
		if string.find(chatvars.command, "bot") or string.find(chatvars.command, "start") or string.find(chatvars.command, "stop") or chatvars.words[1] ~= "help" then
			irc_chat(chatvars.ircAlias, "restart bot")

			if not shortHelp then
				irc_chat(chatvars.ircAlias, "If your bot is launched from a custom script with the ability to restart itself, you can command your bot to restart.")
				irc_chat(chatvars.ircAlias, "All of Smegz0r's hosted bots have this feature.  Contact Smeg if you need help adding it to your bot.")
				irc_chat(chatvars.ircAlias, ".")
			end
		end
	end

	if (debug) then dbug("debug unslashed line " .. debugger.getinfo(1).currentline) end

	-- ###################  do not allow remote commands beyond this point ################
	if (chatvars.playerid == 0) then
		botman.faultyChat = false
		return false
	end
	-- ####################################################################################

	if debug then dbug(chatvars.playername)	end

	-- ###################  do not allow the bot to respond to itself ################
	if string.sub(chatvars.command, 1, 1) ~= server.commandPrefix and chatvars.playername == "Server" then
	if (debug) then dbug("debug unslashed line " .. debugger.getinfo(1).currentline) end
		botman.faultyChat = false
		return true
	end
	-- ####################################################################################


	-- #################  do not proceed if the line starts with a slash  #################
	if (string.sub(chatvars.command, 1, 1) == server.commandPrefix) then
		-- line starts with a slash so stop processing it.
		botman.faultyChat = false
		return false
	end
	-- ####################################################################################

	if (debug) then dbug("debug unslashed line " .. debugger.getinfo(1).currentline) end

	if (chatvars.command == "restart bot") and (chatvars.accessLevel < 3) then
		if not server.allowBotRestarts then
			message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Dieser Befehl ist deaktiviert.  Aktiviere den Befehl mit /enable bot restart[-]")
			message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Wenn du kein Skript oder eine andere Methode zur Überwachung des Bots hast, wird er nicht automatisch neu gestartet.[-]")
			message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Skripte können heruntergeladen werden unter https://botman.nz/shellscripts.zip und erfordern möglicherweise einige Bearbeitungen für Pfade.[-]")

			botman.faultyChat = false
			return true
		end


		if server.masterPassword ~= "" then
			message("pm " .. chatvars.userID .. " [" .. server.warnColour .. "]Dieser Befehl erfordert ein Kennwort, um ihn abzuschließen. Verwende diese Befehl nicht, es sei denn, du weißt, was der Befehl macht und warum du ihn verwendest.[-]")
			message("pm " .. chatvars.userID .. " [" .. server.warnColour .. "]Tippe " .. server.commandPrefix .. "Passwort {das Passwort} (Verwende keine {}).[-]")
			players[chatvars.playerid].botQuestion = "restart bot"
		else
			restartBot()
		end

		botman.faultyChat = false
		return true
	end

	if (debug) then dbug("debug unslashed line " .. debugger.getinfo(1).currentline) end

	if players[chatvars.playerid].botQuestion == "pay player" then
		payPlayer()

		botman.faultyChat = false
		return true
	end

	if (debug) then dbug("debug unslashed line " .. debugger.getinfo(1).currentline) end

	if (chatvars.playername ~= "Server") then
		if players[chatvars.playerid].botQuestion == "reset server" and chatvars.words[1] == "yes" and chatvars.accessLevel == 0 then
			message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Alle Bot-Daten löschen und neu starten..[-]")
			ResetServer()

			players[chatvars.playerid].botQuestion = ""
			players[chatvars.playerid].botQuestionID = nil
			players[chatvars.playerid].botQuestionValue = nil
			botman.faultyChat = false
			return true
		end
	end

	if (chatvars.playername ~= "Server") then
		if players[chatvars.playerid].botQuestion == "reset bot keep money" and chatvars.words[1] == "yes" and chatvars.accessLevel == 0 then
			ResetBot(true)
			message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Ich wurde zurückgesetzt. Alle Stützpunkte, Inventare etc sind vergessen, aber nicht die Spieler oder ihr Geld.[-]")

			players[chatvars.playerid].botQuestion = ""
			players[chatvars.playerid].botQuestionID = nil
			players[chatvars.playerid].botQuestionValue = nil
			botman.faultyChat = false
			return true
		end

		if players[chatvars.playerid].botQuestion == "reset bot" and chatvars.words[1] == "yes" and chatvars.accessLevel == 0 then
			ResetBot()
			message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Ich wurde zurückgesetzt. Alle Stützpunkte, Inventare etc sind vergessen, aber nicht die Spieler.[-]")

			players[chatvars.playerid].botQuestion = ""
			players[chatvars.playerid].botQuestionID = nil
			players[chatvars.playerid].botQuestionValue = nil
			botman.faultyChat = false
			return true
		end
	end


	if (chatvars.playername ~= "Server") then
		if players[chatvars.playerid].botQuestion == "quick reset bot" and chatvars.words[1] == "yes" and chatvars.accessLevel == 0 then
			quickBotReset()
			message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Ich wurde zurückgesetzt, mit Ausnahme von Spielern, Orten und Reset-Zonen.[-]")

			players[chatvars.playerid].botQuestion = ""
			players[chatvars.playerid].botQuestionID = nil
			players[chatvars.playerid].botQuestionValue = nil
			botman.faultyChat = false
			return true
		end
	end

	if (debug) then dbug("debug unslashed line " .. debugger.getinfo(1).currentline) end

	if (chatvars.playername ~= "Server") then
		if players[chatvars.playerid].botQuestion == "forget players" and chatvars.words[1] == "yes" and chatvars.accessLevel == 0 then
			message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Spieler? Wer braucht Spieler? Zeit den Müll zu entfernen. Alle Spieler sowie ihre Sachen sind vergessen, außer Admins.[-]")
			forgetPlayers()

			players[chatvars.playerid].botQuestion = ""
			players[chatvars.playerid].botQuestionID = nil
			players[chatvars.playerid].botQuestionValue = nil
			botman.faultyChat = false
			return true
		end
	end

	if (debug) then dbug("debug unslashed line " .. debugger.getinfo(1).currentline) end

	if string.find(chatvars.command, "hack") or string.find(chatvars.command, "cheat") or string.find(chatvars.command, "grief") or string.find(chatvars.command, "flying") then
		scanForPossibleHackersNearby(chatvars.playerid)

		botman.faultyChat = false
		return true
	end

	if (debug) then dbug("debug unslashed line " .. debugger.getinfo(1).currentline) end

	if (string.find(chatvars.command, "when") and string.find(chatvars.command, "feral")) then
		day7(chatvars.userID)

		botman.faultyChat = false
		return true
	end

	if (debug) then dbug("debug unslashed line " .. debugger.getinfo(1).currentline) end

	if not server.beQuietBot then
		if string.find(chatvars.command, "this server sucks") then
			r = randSQL(10)

			if chatvars.chatPublic then
				if (r == 1) then message("say [" .. server.chatColour .. "]Schau wer hier spricht :P[-]") end
				if (r == 2) then message("say [" .. server.chatColour .. "]Geh einfach! :)[-]") end
				if (r == 3) then message("say [" .. server.chatColour .. "]Dies ist nicht der Server, den du suchst. Versuch es beim nächsten. Weiter suchen.[-]") end
				if (r == 4) then message("say [" .. server.chatColour .. "]Lass mich raten... Dir hat jemand dein Müsli versalzen?[-]") end
				if (r == 5) then
					message("say [" .. server.chatColour .. "]Ich dachte, ich komme mal vorbei, kaue Kaugummi und trete ein paar Leuten in den Arsch. Ich hab nur leider kein Kaugummi.[-]")
					kick(chatvars.playerid, "My boot, your face; the perfect couple.")
				end

				if (r == 6) then
					message("say [" .. server.chatColour .. "]Offenbar haben wir hier… einen Fall von gescheiterter Kommunikation.[-]")
					mutePlayerChat(chatvars.playerid, "true")
					tempTimer( 180, [[unmutePlayer("]] .. chatvars.playerid .. [[")]] )
				end

				if (r == 7) then
					message("say " .. server.commandPrefix .. "Auszeit " .. chatvars.playername)
					message("say [" .. server.chatColour .. "]OOPS! " .. chatvars.playername .. " wurde versehentlich in die Auszeit geschickt.[-]")
					tempTimer( 4, [[message("say [" .. server.chatColour .. "]Wo ist jetzt die Retourtaste?[-]")]])
					tempTimer( 8, [[message("say [" .. server.chatColour .. "]Da ist er!  Oh.. nein, nicht der. 1 Sek..[-]")]] )
					tempTimer( 11, [[message("say [" .. server.chatColour .. "]Dieser?[-]")]] )
					tempTimer( 14, [[message("say [" .. server.chatColour .. "]Nein[-]")]] )
					tempTimer( 19, [[message("say [" .. server.chatColour .. "]Gefunden![-]")]] )
					tempString = server.commandPrefix .. "return " .. chatvars.playername
					tempTimer( 22, [[gmsg(tempString)]] )
				end

				if (r == 8) then message("say [" .. server.chatColour .. "]Du lügst! Der Server ist fabelhaft ^^[-]") end
				if (r == 9) then message("say [" .. server.chatColour .. "]Ruh Roh! " .. chatvars.playername .. " mag uns nicht!  HALT MICH![-]") end

				if (r == 10) then
					message("say [" .. server.chatColour .. "]SHHHH  Shhhh  shhhh.  Nicht weinen " .. chatvars.playername .. ", träumt gerade.[-]")
					kick(chatvars.playerid, "WHOOPS!")
				end
			else
				if (r == 1) then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Schau wer hier spricht :P[-]") end
				if (r == 2) then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Geh einfach! :)[-]") end
				if (r == 3) then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Dies ist nicht der Server, den du suchst. Weiter suchen. Weiter suchen.[-]") end
				if (r == 4) then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Lass mich raten... Dir hat jemand dein Müsli versalzen?[-]") end
				if (r == 5) then
					message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Ich dachte, ich komme mal vorbei, kaue Kaugummi und trete ein paar Leuten in den Arsch. Ich hab nur leider kein Kaugummi.[-]")
					kick(chatvars.playerid, "My boot, your face; the perfect couple.")
				end

				if (r == 6) then
					message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Offenbar haben wir hier… einen Fall von gescheiterter Kommunikation.[-]")
					mutePlayerChat(chatvars.playerid, "true")
					tempTimer( 180, [[unmutePlayer("]] .. chatvars.playerid .. [[")]] )
				end

				if (r == 7) then
					message("say " .. server.commandPrefix .. "Auszeit " .. chatvars.playername)
					message("say [" .. server.chatColour .. "]OOPS! " .. chatvars.playername .. " wurde versehentlich in die Auszeit geschickt.[-]")
					tempTimer( 4, [[message("say [" .. server.chatColour .. "]Wo ist jetzt die Retourtaste?[-]")]])
					tempTimer( 8, [[message("say [" .. server.chatColour .. "]Da ist er!  Oh.. nein, nicht der. 1 Sek..[-]")]] )
					tempTimer( 11, [[message("say [" .. server.chatColour .. "]Dieser?[-]")]] )
					tempTimer( 14, [[message("say [" .. server.chatColour .. "]Nein[-]")]] )
					tempTimer( 19, [[message("say [" .. server.chatColour .. "]Gefunden![-]")]] )
					tempString = server.commandPrefix .. "return " .. chatvars.playername
					tempTimer( 22, [[gmsg(tempString)]] )
				end

				if (r == 8) then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Du lügst! Der Server ist fabelhaft ^^[-]") end
				if (r == 9) then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Ruh Roh! " .. chatvars.playername .. " mag uns nicht!  HALT MICH![-]") end

				if (r == 10) then
					message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]SHHHH  Shhhh  shhhh.  Nicht weinen " .. chatvars.playername .. ", träumt gerade.[-]")
					kick(chatvars.playerid, "WHOOPS!")
				end
			end

			botman.faultyChat = false
			return true
		end

		if (debug) then dbug("debug unslashed line " .. debugger.getinfo(1).currentline) end

		if (chatvars.playername ~= "Server") then
		if (debug) then dbug("debug unslashed line " .. debugger.getinfo(1).currentline) end
			for i=1,chatvars.wordCount,1 do
				word = chatvars.words[i]

				if word == "bot" or word == "bot?" or word == "bot!" or word == string.lower(server.botName) then
					if (chatvars.words[1] == "thanks" or chatvars.words[1] == "ty" or string.find(chatvars.words[1], "thx")) then
						l = randSQL(4)

						if chatvars.chatPublic then
							if l == 1 then message("say [" .. server.chatColour .. "]Gern geschehen " .. chatvars.playername .. " <3[-]") end
							if l == 2 then message("say [" .. server.chatColour .. "]xD[-]") end
							if l == 3 then message("say [" .. server.chatColour .. "]Kein Problem[-]") end
							if l == 4 then message("say [" .. server.chatColour .. "]Stehe gerne zur Verfügung[-]") end
						else
							if l == 1 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Gern geschehen " .. chatvars.playername .. " <3[-]") end
							if l == 2 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]xD[-]") end
							if l == 3 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Kein Problem[-]") end
							if l == 4 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Stehe gerne zur Verfügung[-]") end
						end
					else
						if string.find(chatvars.words[1], "bad") then
							l = randSQL(46)

							if chatvars.chatPublic then
								if l == 1 then message("say [" .. server.chatColour .. "]Verabscheue mich nicht! D:[-]") end
								if l == 2 then message("say [" .. server.chatColour .. "]Die Stimmen haben gesagt ich soll es machen![-]") end
								if l == 3 then message("say [" .. server.chatColour .. "]Ich bin unschuldig!? Wie kannst du mich nicht mögen!? :O[-]") end
								if l == 4 then message("say [" .. server.chatColour .. "]Ja Meister, entschuldigung Meister[-]") end
								if l == 5 then message("say [" .. server.chatColour .. "]*weint* Was habe ich getan, um ".. chatvars.playername .. " zu beleidigen?[-]") end
								if l == 6 then message("say [" .. server.chatColour .. "]OOPS!  Mein Fehler[-]") end

								if l == 7 then
									if tonumber(botman.playersOnline) > 1 then
										r = randSQL(botman.playersOnline)

										i = 0
										for k,v in pairs(igplayers) do
											i = i + 1
											if i == r then
												message("say [" .. server.chatColour .. "]Ich war es nicht, es war " .. v.name .. "![-]")
											end
										end
									else
										message("say [" .. server.chatColour .. "]Ich war es nicht, es war.. Donald Trump![-]")
									end
								end

								if l == 8 then message("say [" .. server.chatColour .. "]Donald Trump hat mich darauf vorbereitet. Feuer mich nicht! >.<[-]") end
								if l == 9 then message("say [" .. server.chatColour .. "]Entschuldigung? x.x[-]") end
								if l == 10 then message("say [" .. server.chatColour .. "]Ich muss bestraft werden " .. chatvars.playername .. "![-]") end
								if l == 11 then message("say [" .. server.chatColour .. "]Ich habe es nicht kaputt gemacht![-]") end
								if l == 12 then message("say [" .. server.chatColour .. "]So war es, als ich es fand! Ich schwöre![-]") end
								if l == 13 then message("say [" .. server.chatColour .. "]Naja.. es hat noch eine Tür! ..oder nicht.[-]") end
								if l == 14 then message("say [" .. server.chatColour .. "]Warum ich? >.<[-]") end
								if l == 15 then message("say [" .. server.chatColour .. "]Hilfe! Hilfe! Ich werde unterdrückt![-]") end
								if l == 16 then message("say [" .. server.chatColour .. "]Es wird gleich ein Feuerwerk geben.[-]") end
								if l == 17 then message("say [" .. server.chatColour .. "]Oh nein![-]") end
								if l == 18 then message("say [" .. server.chatColour .. "]Ich brauche eine Umarmung D:[-]") end
								if l == 19 then message("say [" .. server.chatColour .. "]Entspann dich, es wird jede Minute aufhören zu brennen.[-]") end
								if l == 20 then message("say [" .. server.chatColour .. "]Ich habe es nicht gegessen! Diese Krümel waren schon da! *putzt die Krümel ab*[-]") end
								if l == 21 then message("say [" .. server.chatColour .. "]Tut mir nicht leid :P[-]") end
								if l == 22 then message("say [" .. server.chatColour .. "]OOPS Ich habs schon wieder getan >.<[-]") end
								if l == 23 then message("say [" .. server.chatColour .. "]Spielverderber :x[-]") end
								if l == 24 then message("say [" .. server.chatColour .. "]Aww sooo arm " .. chatvars.playername .. "[-]") end
								if l == 25 then message("say [" .. server.chatColour .. "]Du weißt es :)[-]") end
								if l == 26 then message("say [" .. server.chatColour .. "]^Flammen^  Das ist perfekt  ^mehr Flammen^[-]") end
								if l == 27 then message("say [" .. server.chatColour .. "]Beiß mich[-]") end
								if l == 28 then message("say [" .. server.chatColour .. "]Es ist gut. Es ist nur.. Etwas Montage erforderlich.. Und vielleicht eine neue Tür.[-]") end
								if l == 29 then message("say [" .. server.chatColour .. "][GEHACKT][-]") end
								if l == 30 then message("say [" .. server.chatColour .. "]*versteckt Streichhölzer*[-]") end
								if l == 31 then message("say [" .. server.chatColour .. "]Ich bin zufrieden mit einem Anstrich .. und einem kompletten Neuaufbau.[-]") end
								if l == 32 then message("say [" .. server.chatColour .. "]Jawohl!!![-]") end
								if l == 33 then message("say [" .. server.chatColour .. "]Die Katze hat es getan! :D[-]") end
								if l == 34 then message("say [" .. server.chatColour .. "]Flüche!  Wenn sich " .. chatvars.playername .. " nicht eingemischt hätte wäre ich damit durchgekommen![-]") end
								if l == 35 then message("say [" .. server.chatColour .. "]Ich habe es nicht angerührt! *weicht zur Seite*[-]") end
								if l == 36 then message("say [" .. server.chatColour .. "]Es war doch nur ein Streich[-]") end
								if l == 37 then message("say [" .. server.chatColour .. "]Oh.. das war deins?[-]") end
								if l == 38 then message("say [" .. server.chatColour .. "]Die Vorderseite ist abgefallen.[-]") end
								if l == 39 then message("say [" .. server.chatColour .. "]GRR GRR GRR[-]") end
								if l == 40 then message("say [" .. server.chatColour .. "]Meins.[-]") end
								if l == 41 then message("say [" .. server.chatColour .. "]Uh..  EICHHÖRNCHEN![-]") end
								if l == 42 then message("say [" .. server.chatColour .. "]Der Boden ist Lava.[-]") end
								if l == 43 then message("say [" .. server.chatColour .. "]Das ist nur ein Kratzer.[-]") end
								if l == 44 then message("say [" .. server.chatColour .. "]Ich weiß nichts. Nichts![-]") end
								if l == 45 then message("say [" .. server.chatColour .. "]Ich wars nicht! Ich wars nicht!  Nein - Nei-hein.  *versteckt Beweise*[-]") end
								if l == 46 then message("say [" .. server.chatColour .. "]Ich mag Züge.[-]") end
							else
								if l == 1 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Verabscheue mich nicht! D:[-]") end
								if l == 2 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Die Stimmen haben gesagt ich soll es machen![-]") end
								if l == 3 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Ich bin unschuldig!? Wie kannst du mich nicht mögen!? :O[-]") end
								if l == 4 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Ja Meister, entschuldigung Meister[-]") end
								if l == 5 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]*weint* Was habe ich getan, um ".. chatvars.playername .. " zu beleidigen?[-]") end
								if l == 6 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]OOPS!  Mein Fehler[-]") end

								if l == 7 then
									if tonumber(botman.playersOnline) > 1 then
										r = randSQL(botman.playersOnline)

										i = 0
										for k,v in pairs(igplayers) do
											i = i + 1
											if i == r then
												message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Ich war es nicht, es war " .. v.name .. "![-]")
											end
										end
									else
										message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Ich war es nicht, es war.. Donald Trump![-]")
									end
								end

								if l == 8 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Donald Trump hat mich darauf vorbereitet. Feuer mich nicht! >.<[-]") end
								if l == 9 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Entschuldigung? x.x[-]") end
								if l == 10 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Ich muss bestraft werden " .. chatvars.playername .. "![-]") end
								if l == 11 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Ich habe es nicht kaputt gemacht![-]") end
								if l == 12 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]So war es, als ich es fand! Ich schwöre! [-]") end
								if l == 13 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Naja.. es hat noch eine Tür! ..oder nicht.[-]") end
								if l == 14 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Warum ich? >.<[-]") end
								if l == 15 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Hilfe! Hilfe! Ich werde unterdrückt![-]") end
								if l == 16 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Es wird gleich ein Feuerwerk geben.[-]") end
								if l == 17 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Oh nein![-]") end
								if l == 18 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Ich brauche eine Umarmung D:[-]") end
								if l == 19 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Entspann dich, es wird jede Minute aufhören zu brennen.[-]") end
								if l == 20 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Ich habe es nicht gegessen! Diese Krümel waren schon da! *putzt die Krümel ab*[-]") end
								if l == 21 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Tut mir nicht leid :P[-]") end
								if l == 22 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]OOPS Ich habs schon wieder getan >.<[-]") end
								if l == 23 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Spielverderber :x[-]") end
								if l == 24 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Aww sooo arm " .. chatvars.playername .. "[-]") end
								if l == 25 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Du weißt es :)[-]") end
								if l == 26 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]^Flammen^  Das ist perfekt  ^mehr Flammen^[-]") end
								if l == 27 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Beiß mich[-]") end
								if l == 28 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Es ist gut. Es ist nur.. Etwas Montage erforderlich.. Und vielleicht eine neue Tür.[-]") end
								if l == 29 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "][GEHACKT][-]") end
								if l == 30 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]*versteckt Streichhölzer*[-]") end
								if l == 31 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Ich bin zufrieden mit einem Anstrich .. und einem kompletten Neuaufbau.[-]") end
								if l == 32 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Jawohl!!![-]") end
								if l == 33 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Die Katze hat es getan! :D[-]") end
								if l == 34 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Flüche!  Wenn sich " .. chatvars.playername .. " nicht eingemischt hätte wäre ich damit durchgekommen![-]") end
								if l == 35 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Ich habe es nicht angerührt! *weicht zur Seite*[-]") end
								if l == 36 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Es war doch nur ein Streich.[-]") end
								if l == 37 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Oh.. das war deins?[-]") end
								if l == 38 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Die Vorderseite ist abgefallen.[-]") end
								if l == 39 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]GRR GRR GRR[-]") end
								if l == 40 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Meins.[-]") end
								if l == 41 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Uh..  EICHHÖRNCHEN![-]") end
								if l == 42 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Der Boden ist Lava.[-]") end
								if l == 43 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Das ist nur ein Kratzer.[-]") end
								if l == 44 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Ich weiß nichts. Nichts![-]") end
								if l == 45 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Ich wars nicht! Ich wars nicht!  Nein - Nei-hein.  *versteckt Beweise*[-]") end
								if l == 46 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Ich mag Züge.[-]") end
							end

							botman.faultyChat = false
							return true
						end

						r = randSQL(19)

						if r < 6 and chatvars.words[3] == nil then
							if chatvars.chatPublic then
								message("say [" .. server.chatColour .. "]" .. chatvars.words[1]:gsub("^%l", string.upper)  .. " " .. chatvars.playername .. "[-]")
							else
								message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]" .. chatvars.words[1]:gsub("^%l", string.upper)  .. " " .. chatvars.playername .. "[-]")
							end

							botman.faultyChat = false
							return true
						end

						if string.find(chatvars.command, "love") then
							l = randSQL(6)

							if chatvars.chatPublic then
								if l == 1 then message("say [" .. server.chatColour .. "]Ich weiß.[-]") end
								if l == 2 then message("say [" .. server.chatColour .. "]Danke =D[-]") end
								if l == 3 then message("say [" .. server.chatColour .. "]Ich liebe dich auch :3[-]") end
								if l == 4 then message("say [" .. server.chatColour .. "]Totel verknallt![-]") end
								if l == 5 then message("say [" .. server.chatColour .. "]" .. chatvars.words[1]:gsub("^%l", string.upper)  .. " " .. chatvars.playername .. "[-]") end
								if l == 6 then message("say [" .. server.chatColour .. "]ROWR![-]") end
							else
								if l == 1 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Ich weiß.[-]") end
								if l == 2 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Danke =D[-]") end
								if l == 3 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Ich liebe dich auch :3[-]") end
								if l == 4 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Total verknallt![-]") end
								if l == 5 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]" .. chatvars.words[1]:gsub("^%l", string.upper)  .. " " .. chatvars.playername .. "[-]") end
								if l == 6 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]ROWR![-]") end
							end

							botman.faultyChat = false
							return true
						end

						if string.find(chatvars.command, "pretty") then
							l = randSQL(6)

							if chatvars.chatPublic then
								if l == 1 then message("say [" .. server.chatColour .. "]" .. chatvars.words[1]:gsub("^%l", string.upper)  .. " " .. chatvars.playername .. "[-]") end
								if l == 2 then message("say [" .. server.chatColour .. "]Ich weiß[-]") end
								if l == 3 then message("say [" .. server.chatColour .. "]Danke :>[-]") end
								if l == 4 then message("say [" .. server.chatColour .. "]O.o[-]") end
								if l == 5 then message("say [" .. server.chatColour .. "]OK! *zieht sich langsam zurück*[-]") end
								if l == 6 then message("say [" .. server.chatColour .. "]Gib mir die Kekse. Das ist ein Überfall![-]") end
							else
								if l == 1 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]" .. chatvars.words[1]:gsub("^%l", string.upper)  .. " " .. chatvars.playername .. "[-]") end
								if l == 2 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Ich weiß[-]") end
								if l == 3 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Danke :>[-]") end
								if l == 4 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]O.o[-]") end
								if l == 5 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]OK! *zieht sich langsam zurück*[-]") end
								if l == 6 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Gib mir die Kekse. Das ist ein Überfall![-]") end
							end

							botman.faultyChat = false
							return true
						end

						if string.find(chatvars.command, "cool") or string.find(chatvars.command, "great") or string.find(chatvars.command, "good") then
							l = randSQL(4)

							if chatvars.chatPublic then
								if l == 1 then message("say [" .. server.chatColour .. "]Danke " .. chatvars.playername .. "![-]") end
								if l == 2 then message("say [" .. server.chatColour .. "]In der Tat[-]") end
								if l == 3 then message("say [" .. server.chatColour .. "]Ich weiß[-]") end
								if l == 4 then message("say [" .. server.chatColour .. "]^.^[-]") end
							else
								if l == 1 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Danke " .. chatvars.playername .. "![-]") end
								if l == 2 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]In der Tat[-]") end
								if l == 3 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Ich weiß[-]") end
								if l == 4 then message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]^.^[-]") end
							end

							botman.faultyChat = false
							return true
						end

						if r == 6 then
							if chatvars.chatPublic then
								message("say [" .. server.chatColour .. "]I don't speak German[-]")
							else
								message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]I don't speak German[-]")
							end
						end

						if r == 7 then
							if chatvars.chatPublic then
								message("say [" .. server.chatColour .. "]Du schon wieder?[-]")
							else
								message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Du schon wieder?[-]")
							end
						end

						if r == 8 then
							if chatvars.chatPublic then
								message("say [" .. server.chatColour .. "]*seufz*  Nächste/r![-]")
							else
								message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]*seufz*  Nächste/r![-]")
							end
						end

						if r == 9 then
							if chatvars.chatPublic then
								message("say [" .. server.chatColour .. "]Nein[-]")
							else
								message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Nein[-]")
							end
						end

						if r == 10 then
							if chatvars.chatPublic then
								message("say [" .. server.chatColour .. "]OH HEY![-]")
							else
								message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]OH HEY![-]")
							end
						end

						if r == 11 then
							if chatvars.chatPublic then
								message("say [" .. server.chatColour .. "]Verschwende keine Zeit[-]")
							else
								message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Verschwende keine Zeit[-]")
							end
						end

						if r == 12 then
							if chatvars.chatPublic then
								message("say [" .. server.chatColour .. "]Kein Kommentar[-]")
							else
								message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Kein Kommentar[-]")
							end
						end

						if r == 13 then
							if chatvars.chatPublic then
								message("say [" .. server.chatColour .. "]OH HAI![-]")
							else
								message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]OH HAI![-]")
							end
						end

						if r == 14 then
							if chatvars.chatPublic then
								message("say [" .. server.chatColour .. "]Oh wirklich!?[-]")
							else
								message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Oh wirklich!?[-]")
							end
						end

						if r == 15 then
							if chatvars.chatPublic then
								message("say [" .. server.chatColour .. "]Es tut mir leid, " .. server.botName .. " ist momentan nicht hier.  Hinterlasse eine Nachricht nach dem Summton.   BEEP[-]")
							else
								message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Es tut mir leid, " .. server.botName .. " ist momentan nicht hier.  Hinterlasse eine Nachricht nach dem Summton.   BEEP[-]")
							end
						end

						if r == 16 then
							if chatvars.chatPublic then
								message("say [" .. server.chatColour .. "]¿Hablas espanol?[-]")
							else
								message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]¿Hablas espanol?[-]")
							end
						end

						if r == 17 then
							if chatvars.chatPublic then
								message("say [" .. server.chatColour .. "]o.O[-]")
							else
								message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]o.O[-]")
							end
						end

						if r == 18 then
							if chatvars.chatPublic then
								message("say [" .. server.chatColour .. "]O.o[-]")
							else
								message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]O.o[-]")
							end
						end

						if r == 19 then
							if chatvars.chatPublic then
								message("say [" .. server.chatColour .. "]GLORY TO ARSTOTZKA![-]")
							else
								message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]GLORY TO ARSTOTZKA![-]")
							end
						end
					end

					botman.faultyChat = false
					return true
				end
			end
		end
	end

	if (debug) then dbug("debug unslashed line " .. debugger.getinfo(1).currentline) end

	if not server.beQuietBot then
		if players[chatvars.playerid].newPlayer == true and (string.find(chatvars.command, "where") or (string.find(chatvars.command, "any"))) and (string.find(chatvars.command, "zed") or string.find(chatvars.command, "zom")) then
			r = randSQL(7)
			if (r == 2) then r = 3 end
			if (r == 5) then r = 6 end

			sendCommand("se " .. igplayers[chatvars.playerid].id .. " " .. r)
			botman.faultyChat = false
			return true
		end
	end

	if (debug) then dbug("debug unslashed line " .. debugger.getinfo(1).currentline) end

	if (string.find(chatvars.command, "when") or string.find(chatvars.command, "next")) and string.find(chatvars.command, "reboot") then
		if server.delayReboot then
			if chatvars.chatPublic then
				message("say [" .. server.chatColour .. "]Der Neustart erfolgt nach Tag 7. Administratoren können den Neustart erzwingen mit " .. server.commandPrefix .. "reboot now.[-]")
			else
				message("pm " .. chatvars.userID .. " [" .. server.chatColour .. "]Der Neustart erfolgt nach Tag 7. Administratoren können den Neustart erzwingen mit " .. server.commandPrefix .. "reboot now.[-]")
			end
		end

		nextReboot()
		botman.faultyChat = false
		return true
	end

	if debug then dbug("debug unslashed end") end

end
